# Summary of 4 files

### no_logse_job_parameter in 1 LFNs

| Transform | LFN | Job ID | Site | Peak Mem | Log URL(s) | Occurrences |
| --------- | --- | ------ | ---- | -------- | ---------- | ----------- |
| `247913` | `LFN:/lhcb/MC/Upgrade/XDIGI/00143577/0000/00143577_00000088_1.xdigi` | 963000895 | **LCG.CERN.cern** (3) |  |  | 3 / 3 |

## FatalGaudiError

```
 FATAL error writing to file 00247913_00000006_1.hlt1upgrade_24c1_butokpee.dst (-1) File too large
TBranchElement::WriteBasketImpl       ERROR basket's WriteBuffer failed.
TBranchElement::TBranch::Fill         ERROR Failed to write out basket.

```

A unrecognized fatal error occurred in Gaudi.

| Transform | LFN | Job ID | Site | Peak Mem | Log URL(s) | Occurrences |
| --------- | --- | ------ | ---- | -------- | ---------- | ----------- |
| `247913` | `LFN:/lhcb/MC/Upgrade/XDIGI/00143577/0000/00143577_00000030_1.xdigi` | 962987685 | **LCG.GRIDKA.de** (1) |  | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2FUpgrade%2FLOG%2F00247913%2F0000&task_name=00000017) | 1 / 1 |
|  | `LFN:/lhcb/MC/Upgrade/XDIGI/00143577/0000/00143577_00000038_1.xdigi` | 962967187 | **LCG.GRIDKA.de** (1) |  | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2FUpgrade%2FLOG%2F00247913%2F0000&task_name=00000015) | 1 / 1 |
|  | `LFN:/lhcb/MC/Upgrade/XDIGI/00143577/0000/00143577_00000048_1.xdigi` | 962699891 | **LCG.GRIDKA.de** (1) |  | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2FUpgrade%2FLOG%2F00247913%2F0000&task_name=00000006) | 1 / 1 |
